==> apache-camel-3.14.0-src.zip: apache-camel-3.14.0/core/camel-core-model/src/main/java/org/apache/camel/model/RemovePropertyDefinition.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.model;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;

import org.apache.camel.spi.Metadata;

/**
 * Removes a named property from the message exchange
 */
@Metadata(label = "eip,transformation")
@XmlRootElement(name = "removeProperty")
@XmlAccessorType(XmlAccessType.FIELD)
public class RemovePropertyDefinition extends NoOutputDefinition<RemovePropertyDefinition> {
    @XmlAttribute
    @Deprecated
    private String propertyName;
    @XmlAttribute
    private String name;

    public RemovePropertyDefinition() {
    }

    public RemovePropertyDefinition(String propertyName) {
        setPropertyName(propertyName);
    }

    @Override
    public String toString() {
        return "RemoveProperty[" + getPropertyName() + "]";
    }

    @Override
    public String getShortName() {
        return "removeProperty";
    }

    @Override
    public String getLabel() {
        return "removeProperty[" + getPropertyName() + "]";
    }

    /**
     * Name of property to remove.
     *
     * @deprecated use name instead
     */
    @Deprecated
    public void setPropertyName(String propertyName) {
        this.propertyName = propertyName;
    }

    @Deprecated
    public String getPropertyName() {
        return propertyName;
    }

    public String getName() {
        return name;
    }

    /**
     * Name of property to remove.
     */
    public void setName(String name) {
        this.name = name;
    }
}

==> apache-camel-3.15.0-src.zip: apache-camel-3.15.0/core/camel-core-model/src/main/java/org/apache/camel/model/RemovePropertyDefinition.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.model;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;

import org.apache.camel.spi.Metadata;

/**
 * Removes a named property from the message exchange
 */
@Metadata(label = "eip,transformation")
@XmlRootElement(name = "removeProperty")
@XmlAccessorType(XmlAccessType.FIELD)
public class RemovePropertyDefinition extends NoOutputDefinition<RemovePropertyDefinition> {
    @XmlAttribute
    private String name;

    public RemovePropertyDefinition() {
    }

    public RemovePropertyDefinition(String propertyName) {
        this.name = propertyName;
    }

    @Override
    public String toString() {
        return "RemoveProperty[" + name + "]";
    }

    @Override
    public String getShortName() {
        return "removeProperty";
    }

    @Override
    public String getLabel() {
        return "removeProperty[" + name + "]";
    }

    public String getName() {
        return name;
    }

    /**
     * Name of property to remove.
     */
    public void setName(String name) {
        this.name = name;
    }
}
